"""iisi-app-core public API."""

from .autoload import autoload
from .decorators import (
    adapter,
    clear_default_container,
    component,
    controller,
    get_default_container,
    policy,
    register,
    repository,
    seed,
    service,
    set_default_container,
    usecase,
)
from .exceptions import FeatureDisabledError
from .feature_flags import clear_feature_flag_config, configure_feature_flags, feature_enabled

__all__ = [
    "FeatureDisabledError",
    "adapter",
    "autoload",
    "clear_default_container",
    "clear_feature_flag_config",
    "component",
    "configure_feature_flags",
    "controller",
    "feature_enabled",
    "get_default_container",
    "policy",
    "register",
    "repository",
    "seed",
    "service",
    "set_default_container",
    "usecase",
]

